/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010-2012 University of Bonn. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * FastParsingAction.cpp
 *
 *  Created on: May 9, 2010
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

//#include "CodePatterns/MemDebug.hpp"

#include "config.hpp"
#include "CodePatterns/Log.hpp"
#include "CodePatterns/Verbose.hpp"
#include "World.hpp"

#include <iostream>
#include <string>

#include "Actions/CommandAction/FastParsingAction.hpp"

using namespace MoleCuilder;

// and construct the stuff
#include "FastParsingAction.def"
#include "Action_impl_pre.hpp"
/** =========== define the function ====================== */
ActionState::ptr CommandFastParsingAction::performCall() {
  config *configuration = World::getInstance().getConfig();
  bool oldvalue = configuration->FastParsing;

  configuration->FastParsing = params.fastparsing.get();
  if (configuration->FastParsing)
    LOG(0, "I won't parse trajectories.");
  else
    LOG(0, "I will parse trajectories.");
  return ActionState::ptr(new CommandFastParsingState(oldvalue, params));
}

ActionState::ptr CommandFastParsingAction::performUndo(ActionState::ptr _state) {
  CommandFastParsingState *state = assert_cast<CommandFastParsingState*>(_state.get());

  config *configuration = World::getInstance().getConfig();
  configuration->FastParsing = state->oldvalue;
  if (configuration->FastParsing)
    LOG(0, "I won't parse trajectories.");
  else
    LOG(0, "I will parse trajectories.");

  return ActionState::ptr(_state);
}

ActionState::ptr CommandFastParsingAction::performRedo(ActionState::ptr _state){
  CommandFastParsingState *state = assert_cast<CommandFastParsingState*>(_state.get());

  config *configuration = World::getInstance().getConfig();
  configuration->FastParsing = state->params.fastparsing.get();
  if (configuration->FastParsing)
    LOG(0, "I won't parse trajectories.");
  else
    LOG(0, "I will parse trajectories.");

  return ActionState::ptr(_state);
}

bool CommandFastParsingAction::canUndo() {
  return true;
}

bool CommandFastParsingAction::shouldUndo() {
  return true;
}
/** =========== end of function ====================== */
